@@ -10,13 +10,8 @@ from pydash import _
 
 class HeadersAssertions(BaseRequest):
 
-    def __init__(
-        self,
-        method: Optional[str] = None,
-        endpoint: Optional[str] = None
-    ):
-        super().__init__(method, endpoint)
-        self._header_target = None
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     @then
     def assert_response_headers_contains(self, key: str):
@@ -27,7 +22,7 @@ class HeadersAssertions(BaseRequest):
         AssertThat(self.response.headers).Contains(key)
 
     @then
-    def assert_that_response_header(self, key: str):
+    def assert_response_header(self, key: str):
         self._target = self.response.headers.get(key)
 
     @then
